@@ -11,6 +11,8 @@ links = [
     ("Another link", "http://example.org"),
 ]
 
+albums_sort_attr = ["meta.nokey", "nosuchattribute", "name"]
+
 files_to_copy = (("../watermark.png", "watermark.png"),)
 
 plugins = [
@@ -18,7 +20,6 @@ plugins = [
     "sigal.plugins.copyright",
     "sigal.plugins.extended_caching",
     "sigal.plugins.feeds",
-    "sigal.plugins.nomedia",
     "sigal.plugins.watermark",
     "sigal.plugins.zip_gallery",
 ]
